Contributing
############

We absolutely welcome any code contributions and we hope that this
guide will facilitate an understanding of the ``pydynamicreporting`` code
repository. It is important to note that while the ``pydynamicreporting``
software package is maintained by ANSYS and any submissions will be
reviewed thoroughly before merging, we still seek to foster a community
that can support user questions and develop new features to make this
software a useful tool for all users.  As such, we welcome and encourage
any questions or submissions to this repository.

Please reference the `PyAnsys Developer's Guide <https://dev.docs.pyansys.com/>`_ for the full documentation
regarding contributing to the ``pydynamicreporting`` project.
